Function hexchat_api::command_inner
source · pub fn command_inner(cmd: &str)Expand description
Executes a command in the active Hexchat window. This function is not intended to be used directly.
pub fn command_inner(cmd: &str)Executes a command in the active Hexchat window. This function is not intended to be used directly.