pub fn lib_hexchat_plugin_deinit(
    hexchat: &'static Hexchat,
    callback: Box<DeinitFn>
) -> i32
Invoked indirectly while a plugin is being unloaded. This function will call the deinitialization function that was registered using the dll_entry_points() macro. It will also unhook all the callbacks currently registered forcing them, and their closure state, to drop and thus clean up. Plugin authors should not call this - it’s only public because dll_entry_points() generates code that needs this.