macro_rules! hc_print_th {
    (  ctx = ($network:expr, $channel:expr), $( $arg:tt )* ) => { ... };
    ( $( $arg:tt )* ) => { ... };
}
Similar to hc_print!(), that can be used from spawned threads to print to the active Hexchat window. This should not be invoked from the Hexchat main thread.

use hexchat_api::hc_print_th;
hc_print_th!(fmt, argv, ...);
hc_print_th!(arg);
hc_print_th!(ctx=(network, channel), argv, ...);
hc_print_th!(ctx=(network, channel), arg);

Arguments

  • ctx=(network, channel) - Sets the context to print in.
  • fmt - The format string.
  • argv - The varibale length formatted arguments.