pub struct ThreadSafeContext { /* private fields */ }
A thread-safe version of Context. Its methods automatically execute on the Hexchat main thread. The full set of methods of Context aren’t fully implemented for this struct because some can’t be trusted to produce predictable results from other threads. For instance .set() from a thread would only cause Hexchat to momentarily set its context, but Hexchat’s context could change again at any moment while the other thread is executing.

Implementations

source

impl ThreadSafeContext

source

pub fn get() -> Option<Self>

Gets the current Context wrapped in a ThreadSafeContext object. This method should be called from the Hexchat main thread for it to contain a predictable Context. Executing it from a thread can yield a wrapped Context for an unexpected channel.

source

pub fn find(network: &str, channel: &str) -> Option<Self>

Gets a ThreadSafeContext object associated with the given channel.

Arguments
  • network - The network of the channel to get the context for.
  • channel - The channel to get the context of.
Returns
  • Some(ThreadSafeContext) on success, and None on failure.
source

pub fn print(&self, message: &str) -> Result<(), ContextError>

Prints the message to the ThreadSafeContext object’s Hexchat context. This is how messages can be printed to Hexchat windows apart from the currently active one.

source

pub fn aprint(&self, message: &str)

Prints without waiting for asynchronous completion. This will print faster than .print() because it just stacks up print requests in the timer queue and moves on without blocking. The downside is errors will not be checked. Error messages will, however, still be printed if any occur.

source

pub fn command(&self, command: &str) -> Result<(), ContextError>

Issues a command in the context held by the ThreadSafeContext object.

source

pub fn get_info(&self, info: &str) -> Result<Option<String>, ContextError>

Gets information from the channel/window that the ThreadSafeContext object holds an internal pointer to.

source

pub fn emit_print( &self, event_name: &str, var_args: &[&str] ) -> Result<(), ContextError>

Issues a print event to the context held by the ThreadSafeContext object.

source

pub fn list_get( &self, name: &str ) -> Result<Option<ThreadSafeListIterator>, ContextError>

Gets a ListIterator from the context held by the Context object. If the list doesn’t exist, the OK() result will contain None; otherwise it will hold the listIterator object for the requested list.