pub fn turn_off_threadsafe_features()
Stops and removes the main thread task queue handler. Otherwise it will keep checking the queue while doing nothing useful - which isn’t necessarily bad. Performance is unaffected either way.

Support for main_thread() is on by default. After this function is invoked, main_thread() should not be used and threads in general risk crashing the software if they try to access Hexchat directly without the main_thread(). ThreadSafeContext and ThreadSafeListIterator should also not be used after this function is called, since they rely on main_thread() internally.